vim.g.mapleader = " "
vim.g.maplocalleader = " "

vim.g.have_nerd_font = true

--  To check the current status of your plugins, run
--    :Lazy
--  To update plugins you can run
--    :Lazy update

-- Bootstrap lazy.nvim
local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not (vim.uv or vim.loop).fs_stat(lazypath) then
  local lazyrepo = "https://github.com/folke/lazy.nvim.git"
  local out = vim.fn.system({ "git", "clone", "--filter=blob:none", "--branch=stable", lazyrepo, lazypath })
  if vim.v.shell_error ~= 0 then
    vim.api.nvim_echo({
      { "Failed to clone lazy.nvim:\n", "ErrorMsg" },
      { out, "WarningMsg" },
      { "\nPress any key to exit..." },
    }, true, {})
    vim.fn.getchar()
    os.exit(1)
  end
end
vim.opt.rtp:prepend(lazypath)

-- Make sure to setup `mapleader` and `maplocalleader` before
-- loading lazy.nvim so that mappings are correct.
-- This is also a good place to setup other settings (vim.opt)
vim.g.mapleader = " "
vim.g.maplocalleader = "\\"

-- Setup lazy.nvim
require("lazy").setup({
  spec = {
    -- import your plugins
    { import = "plugins" },
  },
  -- Configure any other settings here. See the documentation for more details.
  -- colorscheme that will be used when installing plugins.
  install = { colorscheme = { "habamax" } },
  -- automatically check for plugin updates
  checker = { enabled = true },
})

ui = {
  -- If you are using a Nerd Font: set icons to an empty table which will use the
  -- default lazy.nvim defined Nerd Font icons, otherwise define a unicode icons table
  icons = vim.g.have_nerd_font and {} or {
  cmd = "⌘",
  config = "🛠",
  event = "📅",
  ft = "📂",
  init = "⚙",
  keys = "🗝",
  plugin = "🔌",
  runtime = "💻",
  require = "🌙",
  source = "📄",
  start = "🚀",
  task = "📌",
  lazy = "💤 ",
 },
}

--                                 ____ __
--   ___ ___  __ _____________    / _(_) /__ ___
--  (_-</ _ \/ // / __/ __/ -_)  / _/ / / -_|_-<
-- /___/\___/\_,_/_/  \__/\__/  /_//_/_/\__/___/
vim.loader.enable()

require ("binds")
require ("settings")
require ("autocommands")

